@@ -1,28 +1,9 @@
 /*
- * Copyright (c) 1999-2001 Alex Zepeda <zipzippy@sonic.net>
- * Copyright (c) 2001-2002 Michael Haeckel <haeckel@kde.org>
+ * SPDX-FileCopyrightText: 1999-2001 Alex Zepeda <zipzippy@sonic.net>
+ * SPDX-FileCopyrightText: 2001-2002 Michael Haeckel <haeckel@kde.org>
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
- * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
- * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
- * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ * SPDX-License-Identifier: BSD-2-Clause
  *
  */
 #include "pop3.h"
@@ -34,7 +15,7 @@ extern "C" {
 
 #include <QCoreApplication>
 #include <QByteArray>
-#include <QRegExp>
+#include <QRegularExpression>
 #include "pop3_debug.h"
 
 #include <KLocalizedString>
@@ -47,6 +28,19 @@ extern "C" {
 
 #include <kio/slaveinterface.h>
 
+#include <string.h>
+
+#ifdef _MSC_VER
+#define strcasecmp _stricmp
+#endif
+
+#ifdef Q_OS_WIN
+// See kio/src/core/kioglobal_p.h
+#define S_IRUSR 0400
+#define S_IWUSR 0200
+#define S_IXUSR 0100
+#endif
+
 #define GREETING_BUF_LEN 1024
 #define MAX_RESPONSE_LEN 512
 #define MAX_COMMANDS 10
@@ -103,8 +97,6 @@ POP3Protocol::POP3Protocol(const QByteArray &pool, const QByteArray &app, bool i
     qCDebug(POP3_LOG);
     //m_cmd = CMD_NONE;
     m_iOldPort = 0;
-    m_tTimeout.tv_sec = 10;
-    m_tTimeout.tv_usec = 0;
     supports_apop = false;
     m_try_apop = true;
     m_try_sasl = true;
@@ -378,7 +370,7 @@ int POP3Protocol::loginAPOP(const char *challenge, KIO::AuthInfo &ai)
 bool POP3Protocol::saslInteract(void *in, AuthInfo &ai)
 {
     qCDebug(POP3_LOG);
-    sasl_interact_t *interact = (sasl_interact_t *)in;
+    auto *interact = (sasl_interact_t *)in;
 
     //some mechanisms do not require username && pass, so don't need a popup
     //window for getting this info
@@ -629,7 +621,7 @@ bool POP3Protocol::pop3_open()
         // use QSslSocket internally
         QNetworkProxy proxy;
         proxy.setType(QNetworkProxy::NoProxy);
-        if (QSslSocket *sock = qobject_cast<QSslSocket *>(socket())) {
+        if (auto *sock = qobject_cast<QSslSocket *>(socket())) {
             sock->setProxy(proxy);
         } else {
             qCWarning(POP3_LOG) << "no socket, cannot set no proxy";
@@ -673,7 +665,8 @@ bool POP3Protocol::pop3_open()
 
         // Does the server support APOP?
         //QString apop_cmd;
-        QRegExp re(QStringLiteral("<[A-Za-z0-9\\.\\-_]+@[A-Za-z0-9\\.\\-_]+>$"), Qt::CaseInsensitive);
+        const QRegularExpression re(QStringLiteral("<[A-Za-z0-9\\.\\-_]+@[A-Za-z0-9\\.\\-_]+>$"),
+                              QRegularExpression::CaseInsensitiveOption);
 
         qCDebug(POP3_LOG) << "greeting: " << greeting;
         int apop_pos = greeting.indexOf(re);
