@@ -1,19 +1,7 @@
 /*
-    Copyright (c) 2010 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2010 Tobias Koenig <tokoe@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "setupwizard.h"
@@ -33,10 +21,9 @@
 #include <QCheckBox>
 #include <QFormLayout>
 #include <QHBoxLayout>
-#include <QLabel>
 #include <QPushButton>
 #include <QRadioButton>
-#include <QRegExpValidator>
+#include <QRegularExpressionValidator>
 
 enum GroupwareServers {
     Citadel,
@@ -51,7 +38,7 @@ enum GroupwareServers {
 
 static QString settingsToUrl(const QWizard *wizard, const QString &protocol)
 {
-    QString desktopFilePath = wizard->property("providerDesktopFilePath").toString();
+    const QString desktopFilePath = wizard->property("providerDesktopFilePath").toString();
     if (desktopFilePath.isEmpty()) {
         return QString();
     }
@@ -61,14 +48,14 @@ static QString settingsToUrl(const QWizard *wizard, const QString &protocol)
         return QString();
     }
 
-    QStringList supportedProtocols = service->property(QStringLiteral("X-DavGroupware-SupportedProtocols")).toStringList();
+    const QStringList supportedProtocols = service->property(QStringLiteral("X-DavGroupware-SupportedProtocols")).toStringList();
     if (!supportedProtocols.contains(protocol)) {
         return QString();
     }
 
     QString pathPattern;
 
-    QString pathPropertyName(QStringLiteral("X-DavGroupware-") + protocol + QStringLiteral("Path"));
+    const QString pathPropertyName(QStringLiteral("X-DavGroupware-") + protocol + QStringLiteral("Path"));
     if (service->property(pathPropertyName).isNull()) {
         return QString();
     }
@@ -77,7 +64,7 @@ static QString settingsToUrl(const QWizard *wizard, const QString &protocol)
 
     QString username = wizard->field(QStringLiteral("credentialsUserName")).toString();
     QString localPart(username);
-    localPart.remove(QRegExp(QLatin1String("@.*$")));
+    localPart.remove(QRegularExpression(QStringLiteral("@.*$")));
     pathPattern.replace(QLatin1String("$user$"), username);
     pathPattern.replace(QLatin1String("$localpart$"), localPart);
     QString providerName;
@@ -123,11 +110,11 @@ static QString settingsToUrl(const QWizard *wizard, const QString &protocol)
             url.setScheme(QStringLiteral("http"));
         }
 
-        QString host = wizard->field(QStringLiteral("connectionHost")).toString();
+        const QString host = wizard->field(QStringLiteral("connectionHost")).toString();
         if (host.isEmpty()) {
             return QString();
         }
-        QStringList hostParts = host.split(QLatin1Char(':'));
+        const QStringList hostParts = host.split(QLatin1Char(':'));
         url.setHost(hostParts.at(0));
         url.setPath(pathPattern);
 
@@ -222,7 +209,7 @@ CredentialsPage::CredentialsPage(QWidget *parent)
     setTitle(i18n("Login Credentials"));
     setSubTitle(i18n("Enter your credentials to login to the groupware server"));
 
-    QFormLayout *layout = new QFormLayout(this);
+    auto *layout = new QFormLayout(this);
 
     mUserName = new QLineEdit;
     layout->addRow(i18n("User:"), mUserName);
@@ -262,7 +249,7 @@ PredefinedProviderPage::PredefinedProviderPage(QWidget *parent)
     setTitle(i18n("Predefined provider found"));
     setSubTitle(i18n("Select if you want to use the auto-detected provider"));
 
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto *layout = new QVBoxLayout(this);
 
     mLabel = new QLabel;
     layout->addWidget(mLabel);
@@ -332,12 +319,12 @@ ServerTypePage::ServerTypePage(QWidget *parent)
     }
     registerField(QStringLiteral("provider"), mProvidersCombo, "currentText");
 
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto *layout = new QVBoxLayout(this);
 
     mServerGroup = new QButtonGroup(this);
     mServerGroup->setExclusive(true);
 
-    QHBoxLayout *hLayout = new QHBoxLayout;
+    auto *hLayout = new QHBoxLayout;
     QRadioButton *button = new QRadioButton(i18n("Use one of those servers:"));
     registerField(QStringLiteral("templateConfiguration"), button);
     mServerGroup->addButton(button);
@@ -389,10 +376,10 @@ ConnectionPage::ConnectionPage(QWidget *parent)
     setSubTitle(i18n("Enter the connection information for the groupware server"));
 
     mLayout = new QFormLayout(this);
-    QRegExp hostnameRegexp(QStringLiteral("^[a-z0-9][.a-z0-9-]*[a-z0-9](?::[0-9]+)?$"));
+    const QRegularExpression hostnameRegexp(QStringLiteral("^[a-z0-9][.a-z0-9-]*[a-z0-9](?::[0-9]+)?$"));
     mHost = new QLineEdit;
     registerField(QStringLiteral("connectionHost*"), mHost);
-    mHost->setValidator(new QRegExpValidator(hostnameRegexp, this));
+    mHost->setValidator(new QRegularExpressionValidator(hostnameRegexp, this));
     mLayout->addRow(i18n("Host"), mHost);
 
     mPath = new QLineEdit;
@@ -504,7 +491,7 @@ CheckPage::CheckPage(QWidget *parent)
     setSubTitle(i18n("You can test now whether the groupware server can be accessed with the current configuration"));
     setFinalPage(true);
 
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto *layout = new QVBoxLayout(this);
 
     QPushButton *button = new QPushButton(i18n("Test Connection"));
     layout->addWidget(button);
@@ -536,7 +523,7 @@ void CheckPage::checkConnection()
     }
 
     // start the dav collections fetch job to test connectivity
-    KDAV::DavCollectionsMultiFetchJob *job = new KDAV::DavCollectionsMultiFetchJob(davUrls, this);
+    auto *job = new KDAV::DavCollectionsMultiFetchJob(davUrls, this);
     connect(job, &KDAV::DavCollectionsMultiFetchJob::result, this, &CheckPage::onFetchDone);
     job->start();
 }
