@@ -1,19 +1,7 @@
 /*
-    Copyright (c) 2010 Grégory Oestreicher <greg@kamago.net>
+    SPDX-FileCopyrightText: 2010 Grégory Oestreicher <greg@kamago.net>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "urlconfigurationdialog.h"
@@ -35,7 +23,7 @@ UrlConfigurationDialog::UrlConfigurationDialog(QWidget *parent)
     , mRemoteProtocolGroup(new QButtonGroup(this))
 {
     QWidget *mainWidget = new QWidget(this);
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(mainWidget);
     mUi.setupUi(mainWidget);
     mUi.credentialsGroup->setVisible(false);
@@ -209,7 +197,7 @@ void UrlConfigurationDialog::onFetchButtonClicked()
     }
 
     KDAV::DavUrl davUrl(url, protocol());
-    KDAV::DavCollectionsFetchJob *job = new KDAV::DavCollectionsFetchJob(davUrl);
+    auto *job = new KDAV::DavCollectionsFetchJob(davUrl);
     connect(job, &KDAV::DavCollectionsFetchJob::result, this, &UrlConfigurationDialog::onCollectionsFetchDone);
     job->start();
 }
@@ -230,7 +218,7 @@ void UrlConfigurationDialog::onCollectionsFetchDone(KJob *job)
         return;
     }
 
-    KDAV::DavCollectionsFetchJob *davJob = qobject_cast< KDAV::DavCollectionsFetchJob *>(job);
+    auto *davJob = qobject_cast< KDAV::DavCollectionsFetchJob *>(job);
 
     const KDAV::DavCollection::List collections = davJob->collections();
 
@@ -251,7 +239,7 @@ void UrlConfigurationDialog::onModelDataChanged(const QModelIndex &topLeft, cons
     fullUrl.setUserInfo(QString());
 
     KDAV::DavUrl davUrl(fullUrl, protocol());
-    KDAV::DavCollectionModifyJob *job = new KDAV::DavCollectionModifyJob(davUrl);
+    auto *job = new KDAV::DavCollectionModifyJob(davUrl);
     job->setProperty(QStringLiteral("displayname"), newName);
     connect(job, &KDAV::DavCollectionModifyJob::result, this, &UrlConfigurationDialog::onChangeDisplayNameFinished);
     job->start();
@@ -285,11 +273,11 @@ void UrlConfigurationDialog::addModelRow(const QString &displayName, const QStri
 
     QList<QStandardItem *> items;
 
-    QStandardItem *displayNameStandardItem = new QStandardItem(displayName);
+    auto *displayNameStandardItem = new QStandardItem(displayName);
     displayNameStandardItem->setEditable(true);
     items << displayNameStandardItem;
 
-    QStandardItem *urlStandardItem = new QStandardItem(url);
+    auto *urlStandardItem = new QStandardItem(url);
     urlStandardItem->setEditable(false);
     items << urlStandardItem;
 
