@@ -1,20 +1,7 @@
 /*
-    Copyright (C) 2015-2017 Krzysztof Nowicki <krissn@op.pl>
+    SPDX-FileCopyrightText: 2015-2017 Krzysztof Nowicki <krissn@op.pl>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "ewsitem.h"
@@ -417,7 +404,7 @@ EwsItem::EwsItem(QXmlStreamReader &reader)
     qRegisterMetaType<EwsOccurrence>();
     qRegisterMetaType<EwsOccurrence::List>();
 
-    EwsItemPrivate *d = reinterpret_cast<EwsItemPrivate *>(this->d.data());
+    auto *d = reinterpret_cast<EwsItemPrivate *>(this->d.data());
 
     // Check what item type are we
     const QStringRef elmName = reader.name();
@@ -496,7 +483,7 @@ EwsItem &EwsItem::operator=(EwsItem &&other)
 
 EwsItemType EwsItem::type() const
 {
-    const EwsItemPrivate *d = reinterpret_cast<const EwsItemPrivate *>(this->d.data());
+    const auto *d = reinterpret_cast<const EwsItemPrivate *>(this->d.data());
     return d->mType;
 }
 
