@@ -1,29 +1,14 @@
 /*
-    Copyright (C) 2015-2018 Krzysztof Nowicki <krissn@op.pl>
+    SPDX-FileCopyrightText: 2015-2018 Krzysztof Nowicki <krissn@op.pl>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "ewsrequest.h"
 
 #include <QTemporaryFile>
 
-#include "ewsclient.h"
 #include "ewsclient_debug.h"
-#include "ewsserverversion.h"
 #include "auth/ewsabstractauth.h"
 
 EwsRequest::EwsRequest(EwsClient &client, QObject *parent)
@@ -141,7 +126,7 @@ void EwsRequest::requestResult(KJob *job)
         }
     }
 
-    KIO::TransferJob *trJob = qobject_cast<KIO::TransferJob *>(job);
+    auto *trJob = qobject_cast<KIO::TransferJob *>(job);
     int resp = trJob->metaData()[QStringLiteral("responsecode")].toUInt();
 
     if (resp == 401 && mClient.auth()) {
