@@ -1,20 +1,7 @@
 /*
-    Copyright (C) 2015-2016 Krzysztof Nowicki <krissn@op.pl>
+    SPDX-FileCopyrightText: 2015-2016 Krzysztof Nowicki <krissn@op.pl>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "ewsglobaltagsreadjob.h"
@@ -42,7 +29,7 @@ EwsGlobalTagsReadJob::~EwsGlobalTagsReadJob()
 
 void EwsGlobalTagsReadJob::start()
 {
-    EwsGetFolderRequest *req = new EwsGetFolderRequest(mClient, this);
+    auto *req = new EwsGetFolderRequest(mClient, this);
     req->setFolderIds(EwsId::List() << EwsId(EwsDIdMsgFolderRoot));
     EwsFolderShape shape(EwsShapeIdOnly);
     shape << EwsResource::globalTagsProperty << EwsResource::globalTagsVersionProperty;
@@ -53,7 +40,7 @@ void EwsGlobalTagsReadJob::start()
 
 void EwsGlobalTagsReadJob::getFolderRequestFinished(KJob *job)
 {
-    EwsGetFolderRequest *req = qobject_cast<EwsGetFolderRequest *>(job);
+    auto *req = qobject_cast<EwsGetFolderRequest *>(job);
 
     if (!req) {
         qCWarning(EWSRES_LOG) << QStringLiteral("Invalid EwsGetFolderRequest job object");
