@@ -1,20 +1,7 @@
 /*
-    Copyright (C) 2015-2017 Krzysztof Nowicki <krissn@op.pl>
+    SPDX-FileCopyrightText: 2015-2017 Krzysztof Nowicki <krissn@op.pl>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef FAKEEWSSERVER_H
@@ -22,6 +9,8 @@
 
 #include <functional>
 
+#include "fakeewsserver_export.h"
+
 #include <QMutex>
 #include <QPointer>
 #include <QTcpServer>
@@ -31,11 +20,11 @@ class FakeEwsConnection;
 class QXmlResultItems;
 class QXmlNamePool;
 
-class Q_DECL_EXPORT FakeEwsServer : public QTcpServer
+class FAKEEWSSERVER_EXPORT FakeEwsServer : public QTcpServer
 {
     Q_OBJECT
 public:
-    class DialogEntry
+    class FAKEEWSSERVER_EXPORT DialogEntry
     {
     public:
         typedef QPair<QString, ushort> HttpResponse;
