@@ -1,24 +1,10 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "folderarchivesettingpage.h"
-#include "folderarchiveaccountinfo.h"
 #include "folderarchiveutil.h"
 
 #include <CollectionRequester>
@@ -32,7 +18,6 @@
 #include <QVBoxLayout>
 #include <QHBoxLayout>
 #include <QLabel>
-#include <QComboBox>
 #include <QDBusReply>
 #include <QDBusInterface>
 #include <QDBusConnectionInterface>
@@ -75,19 +60,18 @@ FolderArchiveAccountInfo::FolderArchiveType FolderArchiveComboBox::type() const
 FolderArchiveSettingPage::FolderArchiveSettingPage(const QString &instanceName, QWidget *parent)
     : QWidget(parent)
     , mInstanceName(instanceName)
-    , mInfo(nullptr)
 {
-    QVBoxLayout *lay = new QVBoxLayout(this);
+    auto *lay = new QVBoxLayout(this);
     mEnabled = new QCheckBox(i18n("Enable"));
     connect(mEnabled, &QCheckBox::toggled, this, &FolderArchiveSettingPage::slotEnableChanged);
     lay->addWidget(mEnabled);
 
-    QHBoxLayout *hbox = new QHBoxLayout;
+    auto *hbox = new QHBoxLayout;
     QLabel *lab = new QLabel(i18nc(
                                  "@label:chooser for the folder that messages will be archived under",
                                  "Archive into:"));
     hbox->addWidget(lab);
-    mArchiveFolder = new Akonadi::CollectionRequester;
+    mArchiveFolder = new Akonadi::CollectionRequester(this);
     mArchiveFolder->setMimeTypeFilter(QStringList() << KMime::Message::mimeType());
     hbox->addWidget(mArchiveFolder);
     lay->addLayout(hbox);
