@@ -1,19 +1,8 @@
 /*
-    Copyright (C) 2011-2013  Daniel Vrátil <dvratil@redhat.com>
-                  2020  Igor Pobiko <igor.poboiko@gmail.com>
+    SPDX-FileCopyrightText: 2011-2013 Daniel Vrátil <dvratil@redhat.com>
+    SPDX-FileCopyrightText: 2020 Igor Pobiko <igor.poboiko@gmail.com>
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-3.0-or-later
 */
 
 #ifndef CALENDARHANDLER_H
