@@ -1,22 +1,8 @@
 /*
-    Copyright (c) 2010 Klarälvdalens Datakonsult AB,
-                       a KDAB Group company <info@kdab.com>
-    Author: Kevin Ottens <kevin@kdab.com>
+    SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+    SPDX-FileContributor: Kevin Ottens <kevin@kdab.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "additemtask.h"
@@ -63,7 +49,7 @@ void AddItemTask::doStart(KIMAP::Session *session)
     KMime::Message::Ptr msg = item().payload<KMime::Message::Ptr>();
     m_messageId = msg->messageID()->asUnicodeString().toUtf8();
 
-    KIMAP::AppendJob *job = new KIMAP::AppendJob(session);
+    auto *job = new KIMAP::AppendJob(session);
     job->setMailBox(mailBox);
     job->setContent(msg->encodedContent(true));
     job->setFlags(fromAkonadiToSupportedImapFlags(item().flags().values(), collection()));
@@ -74,7 +60,7 @@ void AddItemTask::doStart(KIMAP::Session *session)
 
 void AddItemTask::onAppendMessageDone(KJob *job)
 {
-    KIMAP::AppendJob *append = qobject_cast<KIMAP::AppendJob *>(job);
+    auto *append = qobject_cast<KIMAP::AppendJob *>(job);
 
     if (append->error()) {
         qCWarning(IMAPRESOURCE_LOG) << append->errorString();
@@ -93,7 +79,7 @@ void AddItemTask::onAppendMessageDone(KJob *job)
         const QString mailBox = append->mailBox();
 
         if (session->selectedMailBox() != mailBox) {
-            KIMAP::SelectJob *select = new KIMAP::SelectJob(session);
+            auto *select = new KIMAP::SelectJob(session);
             select->setMailBox(mailBox);
 
             connect(select, &KJob::result,
@@ -112,14 +98,14 @@ void AddItemTask::onPreSearchSelectDone(KJob *job)
         qCWarning(IMAPRESOURCE_LOG) << job->errorString();
         cancelTask(job->errorString());
     } else {
-        KIMAP::SelectJob *select = static_cast<KIMAP::SelectJob *>(job);
+        auto *select = static_cast<KIMAP::SelectJob *>(job);
         triggerSearchJob(select->session());
     }
 }
 
 void AddItemTask::triggerSearchJob(KIMAP::Session *session)
 {
-    KIMAP::SearchJob *search = new KIMAP::SearchJob(session);
+    auto *search = new KIMAP::SearchJob(session);
 
     search->setUidBased(true);
 
@@ -127,7 +113,7 @@ void AddItemTask::triggerSearchJob(KIMAP::Session *session)
         search->setTerm(KIMAP::Term(QStringLiteral("Message-ID"), QString::fromLatin1(m_messageId)));
     } else {
         Akonadi::Collection c = collection();
-        UidNextAttribute *uidNext = c.attribute<UidNextAttribute>();
+        auto *uidNext = c.attribute<UidNextAttribute>();
         if (!uidNext) {
             cancelTask(i18n("Could not determine the UID for the newly created message on the server"));
             search->deleteLater();
@@ -154,7 +140,7 @@ void AddItemTask::onSearchDone(KJob *job)
         return;
     }
 
-    KIMAP::SearchJob *search = static_cast<KIMAP::SearchJob *>(job);
+    auto *search = static_cast<KIMAP::SearchJob *>(job);
 
     qint64 uid = 0;
     if (search->results().count() == 1) {
