@@ -1,22 +1,8 @@
 /*
-    Copyright (c) 2010 Klarälvdalens Datakonsult AB,
-                       a KDAB Group company <info@kdab.com>
-    Author: Kevin Ottens <kevin@kdab.com>
+    SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+    SPDX-FileContributor: Kevin Ottens <kevin@kdab.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "changeitemtask.h"
@@ -64,7 +50,7 @@ void ChangeItemTask::doStart(KIMAP::Session *session)
         KMime::Message::Ptr msg = item().payload<KMime::Message::Ptr>();
         m_messageId = msg->messageID()->asUnicodeString().toUtf8();
 
-        KIMAP::AppendJob *job = new KIMAP::AppendJob(session);
+        auto *job = new KIMAP::AppendJob(session);
 
         job->setMailBox(mailBox);
         job->setContent(msg->encodedContent(true));
@@ -78,7 +64,7 @@ void ChangeItemTask::doStart(KIMAP::Session *session)
         job->start();
     } else if (parts().contains("FLAGS")) {
         if (session->selectedMailBox() != mailBox) {
-            KIMAP::SelectJob *select = new KIMAP::SelectJob(session);
+            auto *select = new KIMAP::SelectJob(session);
             select->setMailBox(mailBox);
 
             connect(select, &KIMAP::SelectJob::result, this, &ChangeItemTask::onPreStoreSelectDone);
@@ -108,7 +94,7 @@ void ChangeItemTask::triggerStoreJob()
     const QList<QByteArray> flags = fromAkonadiToSupportedImapFlags(item().flags().values(), item().parentCollection());
     qCDebug(IMAPRESOURCE_LOG) << flags;
 
-    KIMAP::StoreJob *store = new KIMAP::StoreJob(m_session);
+    auto *store = new KIMAP::StoreJob(m_session);
 
     store->setUidBased(true);
     store->setSequenceSet(KIMAP::ImapSet(m_oldUid));
@@ -138,7 +124,7 @@ void ChangeItemTask::onAppendMessageDone(KJob *job)
         return;
     }
 
-    KIMAP::AppendJob *append = qobject_cast<KIMAP::AppendJob *>(job);
+    auto *append = qobject_cast<KIMAP::AppendJob *>(job);
 
     m_newUid = append->uid();
 
@@ -148,7 +134,7 @@ void ChangeItemTask::onAppendMessageDone(KJob *job)
 
     // APPEND does not require a SELECT, so we could be anywhere right now
     if (m_session->selectedMailBox() != append->mailBox()) {
-        KIMAP::SelectJob *select = new KIMAP::SelectJob(m_session);
+        auto *select = new KIMAP::SelectJob(m_session);
         select->setMailBox(append->mailBox());
 
         connect(select, &KIMAP::SelectJob::result, this, &ChangeItemTask::onPreDeleteSelectDone);
@@ -183,7 +169,7 @@ void ChangeItemTask::onPreDeleteSelectDone(KJob *job)
 
 void ChangeItemTask::triggerSearchJob()
 {
-    KIMAP::SearchJob *search = new KIMAP::SearchJob(m_session);
+    auto *search = new KIMAP::SearchJob(m_session);
 
     search->setUidBased(true);
 
@@ -191,7 +177,7 @@ void ChangeItemTask::triggerSearchJob()
         search->setTerm(KIMAP::Term(QStringLiteral("Message-ID"), QString::fromLatin1(m_messageId)));
     } else {
         const auto parent = item().parentCollection();
-        const UidNextAttribute *uidNext = parent.attribute<UidNextAttribute>();
+        const auto *uidNext = parent.attribute<UidNextAttribute>();
         if (!uidNext) {
             qCWarning(IMAPRESOURCE_LOG) << "Failed to determine new uid.";
             cancelTask(i18n("Could not determine the UID for the newly created message on the server"));
@@ -218,7 +204,7 @@ void ChangeItemTask::onSearchDone(KJob *job)
         return;
     }
 
-    KIMAP::SearchJob *search = static_cast<KIMAP::SearchJob *>(job);
+    auto *search = static_cast<KIMAP::SearchJob *>(job);
 
     if (search->results().count() != 1) {
         qCWarning(IMAPRESOURCE_LOG) << "Failed to determine new uid.";
@@ -232,7 +218,7 @@ void ChangeItemTask::onSearchDone(KJob *job)
 
 void ChangeItemTask::triggerDeleteJob()
 {
-    KIMAP::StoreJob *store = new KIMAP::StoreJob(m_session);
+    auto *store = new KIMAP::StoreJob(m_session);
 
     store->setUidBased(true);
     store->setSequenceSet(KIMAP::ImapSet(m_oldUid));
