@@ -1,22 +1,8 @@
 /*
-    Copyright (c) 2010 Klarälvdalens Datakonsult AB,
-                       a KDAB Group company <info@kdab.com>
-    Author: Kevin Ottens <kevin@kdab.com>
+    SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+    SPDX-FileContributor: Kevin Ottens <kevin@kdab.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "movecollectiontask.h"
@@ -73,7 +59,7 @@ void MoveCollectionTask::doStart(KIMAP::Session *session)
     // Some IMAP servers don't allow moving an opened mailbox, so make sure
     // it's not opened (https://bugs.kde.org/show_bug.cgi?id=324932) by examining
     // a non-existent mailbox. We don't use CLOSE in order not to trigger EXPUNGE
-    KIMAP::SelectJob *examine = new KIMAP::SelectJob(session);
+    auto *examine = new KIMAP::SelectJob(session);
     examine->setOpenReadOnly(true);   // use EXAMINE instead of SELECT
     examine->setMailBox(QStringLiteral("IMAP Resource non existing folder %1").arg(QUuid::createUuid().toString()));
     connect(examine, &KIMAP::SelectJob::result, this, &MoveCollectionTask::onExamineDone);
@@ -85,7 +71,7 @@ void MoveCollectionTask::onExamineDone(KJob *job)
     // We deliberately ignore any error here, because the SelectJob will always fail
     // when examining a non-existent mailbox
 
-    KIMAP::SelectJob *examine = static_cast<KIMAP::SelectJob *>(job);
+    auto *examine = static_cast<KIMAP::SelectJob *>(job);
     doRename(examine->session());
 }
 
@@ -105,7 +91,7 @@ void MoveCollectionTask::doRename(KIMAP::Session *session)
     const QString newMailBox = mailBoxForCollections(targetCollection(), collection());
 
     if (oldMailBox != newMailBox) {
-        KIMAP::RenameJob *job = new KIMAP::RenameJob(session);
+        auto *job = new KIMAP::RenameJob(session);
         job->setSourceMailBox(oldMailBox);
         job->setDestinationMailBox(newMailBox);
 
@@ -123,9 +109,9 @@ void MoveCollectionTask::onRenameDone(KJob *job)
         cancelTask(job->errorString());
     } else {
         // Automatically subscribe to the new mailbox name
-        KIMAP::RenameJob *rename = static_cast<KIMAP::RenameJob *>(job);
+        auto *rename = static_cast<KIMAP::RenameJob *>(job);
 
-        KIMAP::SubscribeJob *subscribe = new KIMAP::SubscribeJob(rename->session());
+        auto *subscribe = new KIMAP::SubscribeJob(rename->session());
         subscribe->setMailBox(rename->destinationMailBox());
 
         connect(subscribe, &KIMAP::SubscribeJob::result, this, &MoveCollectionTask::onSubscribeDone);
