@@ -1,21 +1,7 @@
 /*
- * Copyright 2013  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  *
  */
 
@@ -49,7 +35,7 @@ void SearchTask::doStart(KIMAP::Session *session)
         return;
     }
 
-    KIMAP::SelectJob *select = new KIMAP::SelectJob(session);
+    auto *select = new KIMAP::SelectJob(session);
     select->setMailBox(mailbox);
     connect(select, &KJob::finished,
             this, &SearchTask::onSelectDone);
@@ -202,7 +188,7 @@ void SearchTask::doSearch(KIMAP::Session *session)
     qCDebug(IMAPRESOURCE_LOG) << m_query;
 
     Akonadi::SearchQuery query = Akonadi::SearchQuery::fromJSON(m_query.toLatin1());
-    KIMAP::SearchJob *searchJob = new KIMAP::SearchJob(session);
+    auto *searchJob = new KIMAP::SearchJob(session);
     searchJob->setUidBased(true);
 
     KIMAP::Term term = recursiveEmailTermMapping(query.term());
@@ -229,7 +215,7 @@ void SearchTask::onSearchDone(KJob *job)
         return;
     }
 
-    KIMAP::SearchJob *searchJob = qobject_cast<KIMAP::SearchJob *>(job);
+    auto *searchJob = qobject_cast<KIMAP::SearchJob *>(job);
     const QVector<qint64> result = searchJob->results();
     qCDebug(IMAPRESOURCE_LOG) << result.count() << "matches";
 
