@@ -1,21 +1,8 @@
 /*
-    Copyright (c) 2008 Volker Krause <vkrause@kde.org>
-    Copyright (c) 2008 Omat Holding B.V. <info@omat.nl>
+    SPDX-FileCopyrightText: 2008 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2008 Omat Holding B.V. <info@omat.nl>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "settings.h"
@@ -124,7 +111,7 @@ void Settings::onWalletOpened(bool success)
     if (!success) {
         Q_EMIT passwordRequestCompleted(QString(), true);
     } else {
-        Wallet *wallet = qobject_cast<Wallet *>(sender());
+        auto *wallet = qobject_cast<Wallet *>(sender());
         bool passwordNotStoredInWallet = true;
         if (wallet && wallet->hasFolder(QStringLiteral("imap"))) {
             wallet->setFolder(QStringLiteral("imap"));
@@ -292,7 +279,7 @@ void Settings::renameRootCollection(const QString &newName)
 {
     Akonadi::Collection rootCollection;
     rootCollection.setRemoteId(rootRemoteId());
-    Akonadi::CollectionFetchJob *fetchJob
+    auto *fetchJob
         = new Akonadi::CollectionFetchJob(rootCollection, Akonadi::CollectionFetchJob::Base);
     fetchJob->setProperty("collectionName", newName);
     connect(fetchJob, &KJob::result,
@@ -303,7 +290,7 @@ void Settings::onRootCollectionFetched(KJob *job)
 {
     const QString newName = job->property("collectionName").toString();
     Q_ASSERT(!newName.isEmpty());
-    Akonadi::CollectionFetchJob *fetchJob = static_cast<Akonadi::CollectionFetchJob *>(job);
+    auto *fetchJob = static_cast<Akonadi::CollectionFetchJob *>(job);
     if (fetchJob->collections().size() == 1) {
         Akonadi::Collection rootCollection = fetchJob->collections().at(0);
         rootCollection.setName(newName);
