@@ -1,21 +1,10 @@
 /* This file is part of the KDE project
-   Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
-   Copyright (c) 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
-   Copyright (C) 2009 Kevin Ottens <ervin@kde.org>
-   Copyright (C) 2006-2008 Omat Holding B.V. <info@omat.nl>
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   SPDX-FileCopyrightText: 2010 Casey Link <unnamedrambler@gmail.com>
+   SPDX-FileCopyrightText: 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+   SPDX-FileCopyrightText: 2009 Kevin Ottens <ervin@kde.org>
+   SPDX-FileCopyrightText: 2006-2008 Omat Holding B.V. <info@omat.nl>
 
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef SETUPSERVER_H
@@ -25,7 +14,7 @@
 #include <collection.h>
 #include <KJob>
 
-#include <QRegExpValidator>
+#include <QRegularExpressionValidator>
 class QPushButton;
 class QComboBox;
 namespace Ui {
@@ -79,15 +68,15 @@ private:
     void readSettings();
     void populateDefaultAuthenticationOptions();
 
-    ImapResourceBase *m_parentResource = nullptr;
-    Ui::SetupServerView *m_ui = nullptr;
+    ImapResourceBase *const m_parentResource;
+    Ui::SetupServerView *const m_ui;
     MailTransport::ServerTest *m_serverTest = nullptr;
     bool m_subscriptionsChanged = false;
     bool m_shouldClearCache = false;
     QString m_vacationFileName;
     KIdentityManagement::IdentityCombo *m_identityCombobox = nullptr;
     QString m_oldResourceName;
-    QRegExpValidator mValidator;
+    QRegularExpressionValidator mValidator;
     Akonadi::Collection mOldTrash;
     FolderArchiveSettingPage *m_folderArchiveSettingPage = nullptr;
     QPushButton *mOkButton = nullptr;
