@@ -1,22 +1,8 @@
 /*
-    Copyright (c) 2014 Klarälvdalens Datakonsult AB,
-                       a KDAB Group company <info@kdab.com>
-    Author: Kevin Krammer <kevin.krammer@kdab.com>
+    SPDX-FileCopyrightText: 2014 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+    SPDX-FileContributor: Kevin Krammer <kevin.krammer@kdab.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kolabchangeitemsrelationstask.h"
@@ -39,8 +25,6 @@
 
 KolabChangeItemsRelationsTask::KolabChangeItemsRelationsTask(const ResourceStateInterface::Ptr &resource, QObject *parent)
     : KolabRelationResourceTask(resource, parent)
-    , mSession(nullptr)
-    , mAdding(false)
 {
 }
 
@@ -73,7 +57,7 @@ void KolabChangeItemsRelationsTask::processNextRelation()
 
     //We have to fetch it again in case it changed since the notification was emitted (which is likely)
     //Otherwise we get an empty remoteid for new tags that were immediately applied on an item
-    Akonadi::RelationFetchJob *fetch = new Akonadi::RelationFetchJob(relation);
+    auto *fetch = new Akonadi::RelationFetchJob(relation);
     connect(fetch, &KJob::result, this, &KolabChangeItemsRelationsTask::onRelationFetchDone);
 }
 
@@ -119,7 +103,7 @@ void KolabChangeItemsRelationsTask::onItemsFetched(KJob *job)
         processNextRelation();
         return;
     }
-    Akonadi::ItemFetchJob *fetchJob = static_cast<Akonadi::ItemFetchJob *>(job);
+    auto *fetchJob = static_cast<Akonadi::ItemFetchJob *>(job);
     if (fetchJob->items().size() != 2) {
         qCWarning(KOLABRESOURCE_LOG) << "Invalid number of items retrieved: " << fetchJob->items().size();
         processNextRelation();
@@ -144,7 +128,7 @@ void KolabChangeItemsRelationsTask::onItemsFetched(KJob *job)
     const QLatin1String productId("Akonadi-Kolab-Resource");
     const KMime::Message::Ptr message = Kolab::KolabObjectWriter::writeRelation(relation, members, Kolab::KolabV3, productId);
 
-    KIMAP::AppendJob *appendJob = new KIMAP::AppendJob(mSession);
+    auto *appendJob = new KIMAP::AppendJob(mSession);
     appendJob->setMailBox(mailBoxForCollection(relationCollection()));
     appendJob->setContent(message->encodedContent(true));
     appendJob->setInternalDate(message->date()->dateTime());
@@ -159,7 +143,7 @@ void KolabChangeItemsRelationsTask::removeRelation(const Akonadi::Relation &rela
     const QString mailBox = mailBoxForCollection(relationCollection());
 
     if (mSession->selectedMailBox() != mailBox) {
-        KIMAP::SelectJob *select = new KIMAP::SelectJob(mSession);
+        auto *select = new KIMAP::SelectJob(mSession);
         select->setMailBox(mailBox);
 
         connect(select, &KJob::result, this, &KolabChangeItemsRelationsTask::onSelectDone);
@@ -187,7 +171,7 @@ void KolabChangeItemsRelationsTask::triggerStoreJob()
 
     qCDebug(KOLABRESOURCE_TRACE) << set.toImapSequenceSet();
 
-    KIMAP::StoreJob *store = new KIMAP::StoreJob(mSession);
+    auto *store = new KIMAP::StoreJob(mSession);
     store->setUidBased(true);
     store->setSequenceSet(set);
     store->setFlags(QList<QByteArray>() << ImapFlags::Deleted);
