@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2014 Christian Mollekopf <mollekopf@kolabsys.com>
+    SPDX-FileCopyrightText: 2014 Christian Mollekopf <mollekopf@kolabsys.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kolabhelpers.h"
@@ -246,7 +233,7 @@ static KContacts::ContactGroup convertToGidOnly(const KContacts::ContactGroup &c
             // in the addressbook to get name+email from the UID.
 
             const Akonadi::Item item(reference.uid().toLongLong());
-            Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(item);
+            auto *job = new Akonadi::ItemFetchJob(item);
             job->fetchScope().fetchFullPayload();
             if (!job->exec()) {
                 continue;
