@@ -1,20 +1,8 @@
 /*
 
-    Copyright (C) 2012  Christian Mollekopf <chrigi_1@fastmail.fm>
+    SPDX-FileCopyrightText: 2012 Christian Mollekopf <chrigi_1@fastmail.fm>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "imip.h"
@@ -76,7 +64,7 @@ KMime::Message::Ptr createMessage(const QString &from, const QString &_to, const
         message->contentType()->setParameter(QStringLiteral("method"), QStringLiteral("request"));
 
         if (!attachment.isEmpty()) {
-            KMime::Headers::ContentDisposition *disposition
+            auto *disposition
                 = new KMime::Headers::ContentDisposition();
             disposition->setDisposition(KMime::Headers::CDinline);
             message->setHeader(disposition);
@@ -94,8 +82,8 @@ KMime::Message::Ptr createMessage(const QString &from, const QString &_to, const
         ct->setCategory(KMime::Headers::CCcontainer);
 
         // Set the first multipart, the body message.
-        KMime::Content *bodyMessage = new KMime::Content;
-        KMime::Headers::ContentDisposition *bodyDisposition
+        auto *bodyMessage = new KMime::Content;
+        auto *bodyDisposition
             = new KMime::Headers::ContentDisposition();
         bodyDisposition->setDisposition(KMime::Headers::CDinline);
         bodyMessage->contentType()->setMimeType("text/plain");
@@ -106,8 +94,8 @@ KMime::Message::Ptr createMessage(const QString &from, const QString &_to, const
 
         // Set the sedcond multipart, the attachment.
         if (!attachment.isEmpty()) {
-            KMime::Content *attachMessage = new KMime::Content;
-            KMime::Headers::ContentDisposition *attachDisposition
+            auto *attachMessage = new KMime::Content;
+            auto *attachDisposition
                 = new KMime::Headers::ContentDisposition();
             attachDisposition->setDisposition(KMime::Headers::CDattachment);
             attachMessage->contentType()->setMimeType("text/calendar");
