@@ -1,22 +1,8 @@
 /*
-    Copyright (c) 2014 Klarälvdalens Datakonsult AB,
-                       a KDAB Group company <info@kdab.com>
-    Author: Kevin Krammer <kevin.krammer@kdab.com>
+    SPDX-FileCopyrightText: 2014 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+    SPDX-FileContributor: Kevin Krammer <kevin.krammer@kdab.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "tagchangehelper.h"
@@ -99,7 +85,7 @@ void TagChangeHelper::recordNewUid(qint64 newUid, const Akonadi::Tag &tag)
     Akonadi::Tag updateTag;
     updateTag.setId(tag.id());
     updateTag.setRemoteId(remoteId);
-    Akonadi::TagModifyJob *modJob = new Akonadi::TagModifyJob(updateTag);
+    auto *modJob = new Akonadi::TagModifyJob(updateTag);
     connect(modJob, &KJob::result, this, &TagChangeHelper::onModifyDone);
 }
 
@@ -108,7 +94,7 @@ void TagChangeHelper::onReplaceDone(KJob *job)
     if (job->error()) {
         qCWarning(KOLABRESOURCE_LOG) << "Replace failed: " << job->errorString();
     }
-    UpdateMessageJob *replaceJob = static_cast<UpdateMessageJob *>(job);
+    auto *replaceJob = static_cast<UpdateMessageJob *>(job);
     const qint64 newUid = replaceJob->newUid();
     const Akonadi::Tag tag = job->property("tag").value<Akonadi::Tag>();
     if (newUid > 0) {
