@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2014 Christian Mollekopf <mollekopf@kolabsys.com>
+    SPDX-FileCopyrightText: 2014 Christian Mollekopf <mollekopf@kolabsys.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "updatemessagejob.h"
@@ -23,10 +10,8 @@
 #include <KIMAP/SearchJob>
 #include <KIMAP/SelectJob>
 #include <KIMAP/StoreJob>
-#include <KIMAP/FetchJob>
 #include <KIMAP/ImapSet>
 #include "kolabresource_debug.h"
-#include <KMime/Message>
 #include <replacemessagejob.h>
 
 #include "imapflags.h"
@@ -41,7 +26,6 @@ UpdateMessageJob::UpdateMessageJob(const KMime::Message::Ptr &msg, KIMAP::Sessio
     , mMailbox(mailbox)
     , mUidNext(uidNext)
     , mOldUid(oldUid)
-    , mNewUid(-1)
     , mMessageId(msg->messageID()->asUnicodeString().toUtf8())
     , mKolabUid(kolabUid)
     , mMerger(merger)
@@ -52,7 +36,7 @@ UpdateMessageJob::UpdateMessageJob(const KMime::Message::Ptr &msg, KIMAP::Sessio
 void UpdateMessageJob::start()
 {
     if (mSession->selectedMailBox() != mMailbox) {
-        KIMAP::SelectJob *select = new KIMAP::SelectJob(mSession);
+        auto *select = new KIMAP::SelectJob(mSession);
         select->setMailBox(mMailbox);
         connect(select, &KIMAP::SelectJob::result, this, [this](KJob *job) {
             onSelectDone(job);
@@ -76,7 +60,7 @@ void UpdateMessageJob::onSelectDone(KJob *job)
 
 void UpdateMessageJob::fetchHeaders()
 {
-    KIMAP::FetchJob *fetchJob = new KIMAP::FetchJob(mSession);
+    auto *fetchJob = new KIMAP::FetchJob(mSession);
 
     fetchJob->setSequenceSet(KIMAP::ImapSet(mOldUid));
     fetchJob->setUidBased(true);
@@ -118,7 +102,7 @@ void UpdateMessageJob::onHeadersFetchDone(KJob *job)
 
 void UpdateMessageJob::searchForLatestVersion()
 {
-    KIMAP::SearchJob *search = new KIMAP::SearchJob(mSession);
+    auto *search = new KIMAP::SearchJob(mSession);
     search->setUidBased(true);
     search->setTerm(KIMAP::Term(KIMAP::Term::Subject, QString::fromLatin1(mKolabUid)));
     connect(search, &KJob::result,
@@ -135,7 +119,7 @@ void UpdateMessageJob::onSearchDone(KJob *job)
         return;
     }
 
-    KIMAP::SearchJob *search = static_cast<KIMAP::SearchJob *>(job);
+    auto *search = static_cast<KIMAP::SearchJob *>(job);
 
     if (search->results().count() >= 1) {
         mOldUids = KIMAP::ImapSet();
@@ -143,7 +127,7 @@ void UpdateMessageJob::onSearchDone(KJob *job)
             mOldUids.add(id);
         }
 
-        KIMAP::FetchJob *fetchJob = new KIMAP::FetchJob(mSession);
+        auto *fetchJob = new KIMAP::FetchJob(mSession);
         fetchJob->setSequenceSet(mOldUids);
         fetchJob->setUidBased(true);
 
@@ -183,7 +167,7 @@ void UpdateMessageJob::onConflictingMessageFetchDone(KJob *job)
 void UpdateMessageJob::appendMessage()
 {
     const qint64 uidNext = -1;
-    ReplaceMessageJob *replace = new ReplaceMessageJob(mMessage, mSession, mMailbox, uidNext, mOldUids, this);
+    auto *replace = new ReplaceMessageJob(mMessage, mSession, mMailbox, uidNext, mOldUids, this);
     connect(replace, &KJob::result, this, &UpdateMessageJob::onReplaceDone);
     replace->start();
 }
@@ -196,7 +180,7 @@ void UpdateMessageJob::onReplaceDone(KJob *job)
         emitResult();
         return;
     }
-    ReplaceMessageJob *replaceJob = static_cast<ReplaceMessageJob *>(job);
+    auto *replaceJob = static_cast<ReplaceMessageJob *>(job);
     mNewUid = replaceJob->newUid();
     emitResult();
 }
