@@ -1,24 +1,12 @@
 /*
- *   Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
- *   Copyright (c) 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+ *   SPDX-FileCopyrightText: 2010 Casey Link <unnamedrambler@gmail.com>
+ *   SPDX-FileCopyrightText: 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
  *   This file includes code from old files from previous KDE versions:
- *   Copyright (c) 2003 Andreas Gungl <a.gungl@gmx.de>
- *   Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
+ *   SPDX-FileCopyrightText: 2003 Andreas Gungl <a.gungl@gmx.de>
+ *   SPDX-FileCopyrightText: 1996-1998 Stefan Taferner <taferner@kde.org>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License along
- *   with this program; if not, write to the Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *   SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
@@ -113,7 +101,7 @@ MessageStatus &KMIndexData::status()
             // status and merge it in.
             // This is kept to provide an upgrade path from the old single
             // status to the new multiple status scheme.
-            KMLegacyMsgStatus legacyMsgStatus = (KMLegacyMsgStatus)mCachedLongParts[KMIndexReader::MsgLegacyStatusPart];
+            auto legacyMsgStatus = (KMLegacyMsgStatus)mCachedLongParts[KMIndexReader::MsgLegacyStatusPart];
             mStatus.setRead();
             switch (legacyMsgStatus) {
             case KMLegacyMsgStatusUnknown:
