@@ -1,23 +1,10 @@
 /*  This file is part of the KDE project
-    Copyright (c) 2007 Till Adam <adam@kde.org>
-    Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-    Author: Kevin Krammer, krake@kdab.com
-    Copyright (C) 2011 Kevin Krammer <kevin.krammer@gmx.at>
+    SPDX-FileCopyrightText: 2007 Till Adam <adam@kde.org>
+    SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+    SPDX-FileContributor: Kevin Krammer <krake@kdab.com>
+    SPDX-FileCopyrightText: 2011 Kevin Krammer <kevin.krammer@gmx.at>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "mixedmaildirresource.h"
@@ -226,7 +213,7 @@ void MixedMaildirResource::retrieveItems(const Collection &col)
         return;
     }
 
-    RetrieveItemsJob *job = new RetrieveItemsJob(col, mStore, this);
+    auto *job = new RetrieveItemsJob(col, mStore, this);
     connect(job, &RetrieveItemsJob::result, this, &MixedMaildirResource::retrieveItemsResult);
 
     Q_EMIT status(Running, i18nc("@info:status", "Synchronizing email folder %1", col.name()));
@@ -443,7 +430,7 @@ void MixedMaildirResource::retrieveCollectionsResult(KJob *job)
         return;
     }
 
-    FileStore::CollectionFetchJob *fetchJob = qobject_cast<FileStore::CollectionFetchJob *>(job);
+    auto *fetchJob = qobject_cast<FileStore::CollectionFetchJob *>(job);
     Q_ASSERT(fetchJob != nullptr);
 
     Collection topLevelCollection = mStore->topLevelCollection();
@@ -466,7 +453,7 @@ void MixedMaildirResource::retrieveItemsResult(KJob *job)
         return;
     }
 
-    RetrieveItemsJob *retrieveJob = qobject_cast<RetrieveItemsJob *>(job);
+    auto *retrieveJob = qobject_cast<RetrieveItemsJob *>(job);
     Q_ASSERT(retrieveJob != nullptr);
 
     // messages marked as deleted have been deleted from mbox files but never got purged
@@ -533,7 +520,7 @@ void MixedMaildirResource::retrieveItemResult(KJob *job)
         return;
     }
 
-    FileStore::ItemFetchJob *fetchJob = qobject_cast<FileStore::ItemFetchJob *>(job);
+    auto *fetchJob = qobject_cast<FileStore::ItemFetchJob *>(job);
     Q_ASSERT(fetchJob != nullptr);
     Q_ASSERT(!fetchJob->items().isEmpty());
 
@@ -549,7 +536,7 @@ void MixedMaildirResource::itemAddedResult(KJob *job)
         return;
     }
 
-    FileStore::ItemCreateJob *itemJob = qobject_cast<FileStore::ItemCreateJob *>(job);
+    auto *itemJob = qobject_cast<FileStore::ItemCreateJob *>(job);
     Q_ASSERT(itemJob != nullptr);
 
     /*  qCDebug(MIXEDMAILDIRRESOURCE_LOG) << "item.id=" << itemJob->item().id() << "remoteId=" << itemJob->item().remoteId();*/
@@ -567,7 +554,7 @@ void MixedMaildirResource::itemChangedResult(KJob *job)
         return;
     }
 
-    FileStore::ItemModifyJob *itemJob = qobject_cast<FileStore::ItemModifyJob *>(job);
+    auto *itemJob = qobject_cast<FileStore::ItemModifyJob *>(job);
     Q_ASSERT(itemJob != nullptr);
 
     changeCommitted(itemJob->item());
@@ -591,7 +578,7 @@ void MixedMaildirResource::itemMovedResult(KJob *job)
         return;
     }
 
-    FileStore::ItemMoveJob *itemJob = qobject_cast<FileStore::ItemMoveJob *>(job);
+    auto *itemJob = qobject_cast<FileStore::ItemMoveJob *>(job);
     Q_ASSERT(itemJob != nullptr);
 
     changeCommitted(itemJob->item());
@@ -617,7 +604,7 @@ void MixedMaildirResource::itemRemovedResult(KJob *job)
         return;
     }
 
-    FileStore::ItemDeleteJob *itemJob = qobject_cast<FileStore::ItemDeleteJob *>(job);
+    auto *itemJob = qobject_cast<FileStore::ItemDeleteJob *>(job);
     Q_ASSERT(itemJob != nullptr);
 
     changeCommitted(itemJob->item());
@@ -645,7 +632,7 @@ void MixedMaildirResource::collectionAddedResult(KJob *job)
         return;
     }
 
-    FileStore::CollectionCreateJob *colJob = qobject_cast<FileStore::CollectionCreateJob *>(job);
+    auto *colJob = qobject_cast<FileStore::CollectionCreateJob *>(job);
     Q_ASSERT(colJob != nullptr);
 
     changeCommitted(colJob->collection());
@@ -660,7 +647,7 @@ void MixedMaildirResource::collectionChangedResult(KJob *job)
         return;
     }
 
-    FileStore::CollectionModifyJob *colJob = qobject_cast<FileStore::CollectionModifyJob *>(job);
+    auto *colJob = qobject_cast<FileStore::CollectionModifyJob *>(job);
     Q_ASSERT(colJob != nullptr);
 
     changeCommitted(colJob->collection());
@@ -677,7 +664,7 @@ void MixedMaildirResource::collectionMovedResult(KJob *job)
         return;
     }
 
-    FileStore::CollectionMoveJob *colJob = qobject_cast<FileStore::CollectionMoveJob *>(job);
+    auto *colJob = qobject_cast<FileStore::CollectionMoveJob *>(job);
     Q_ASSERT(colJob != nullptr);
 
     changeCommitted(colJob->collection());
@@ -694,7 +681,7 @@ void MixedMaildirResource::collectionRemovedResult(KJob *job)
         return;
     }
 
-    FileStore::CollectionDeleteJob *colJob = qobject_cast<FileStore::CollectionDeleteJob *>(job);
+    auto *colJob = qobject_cast<FileStore::CollectionDeleteJob *>(job);
     Q_ASSERT(colJob != nullptr);
 
     changeCommitted(colJob->collection());
@@ -717,7 +704,7 @@ void MixedMaildirResource::compactStoreResult(KJob *job)
         return;
     }
 
-    FileStore::StoreCompactJob *compactJob = qobject_cast<FileStore::StoreCompactJob *>(job);
+    auto *compactJob = qobject_cast<FileStore::StoreCompactJob *>(job);
     Q_ASSERT(compactJob != nullptr);
 
     const Item::List items = compactJob->changedItems();
@@ -762,7 +749,7 @@ void MixedMaildirResource::processNextTagContext()
     const TagContext tagContext = mPendingTagContexts.front();
     mPendingTagContexts.pop_front();
 
-    ItemFetchJob *fetchJob = new ItemFetchJob(tagContext.mItem);
+    auto *fetchJob = new ItemFetchJob(tagContext.mItem);
     fetchJob->setProperty("tagList", tagContext.mTagList);
     connect(fetchJob, &ItemFetchJob::result, this, &MixedMaildirResource::tagFetchJobResult);
 }
@@ -775,7 +762,7 @@ void MixedMaildirResource::tagFetchJobResult(KJob *job)
         return;
     }
 
-    ItemFetchJob *fetchJob = qobject_cast<ItemFetchJob *>(job);
+    auto *fetchJob = qobject_cast<ItemFetchJob *>(job);
     Q_ASSERT(fetchJob != nullptr);
 
     Q_ASSERT(!fetchJob->items().isEmpty());
