@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2009 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2009 Tobias Koenig <tokoe@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "openxchangeresource.h"
@@ -294,7 +281,7 @@ OpenXchangeResource::OpenXchangeResource(const QString &id)
     mResourceCollection.setName(name());
     mResourceCollection.setContentMimeTypes(QStringList() << Collection::mimeType());
     mResourceCollection.setRights(Collection::ReadOnly);
-    EntityDisplayAttribute *attribute = mResourceCollection.attribute<EntityDisplayAttribute>(Collection::AddIfMissing);
+    auto *attribute = mResourceCollection.attribute<EntityDisplayAttribute>(Collection::AddIfMissing);
     attribute->setIconName(QStringLiteral("ox"));
 
     Collection privateFolder;
@@ -390,7 +377,7 @@ void OpenXchangeResource::onReloadConfiguration()
     // user id to name as well, so the mapping must be loaded as well.
     // Both is done by UpdateUsersJob, so trigger it here before we continue
     // with synchronization in onUpdateUsersJobFinished.
-    OXA::UpdateUsersJob *job = new OXA::UpdateUsersJob(this);
+    auto *job = new OXA::UpdateUsersJob(this);
     connect(job, &OXA::UpdateUsersJob::result, this, &OpenXchangeResource::onUpdateUsersJobFinished);
     job->start();
 }
@@ -400,11 +387,11 @@ void OpenXchangeResource::retrieveCollections()
     //qDebug("tokoe: retrieve collections called");
     if (Settings::self()->useIncrementalUpdates()) {
         //qDebug( "lastSync=%llu", Settings::self()->foldersLastSync() );
-        OXA::FoldersRequestDeltaJob *job = new OXA::FoldersRequestDeltaJob(Settings::self()->foldersLastSync(), this);
+        auto *job = new OXA::FoldersRequestDeltaJob(Settings::self()->foldersLastSync(), this);
         connect(job, &OXA::UpdateUsersJob::result, this, &OpenXchangeResource::onFoldersRequestDeltaJobFinished);
         job->start();
     } else {
-        OXA::FoldersRequestJob *job = new OXA::FoldersRequestJob(0, OXA::FoldersRequestJob::Modified, this);
+        auto *job = new OXA::FoldersRequestJob(0, OXA::FoldersRequestJob::Modified, this);
         connect(job, &OXA::UpdateUsersJob::result, this, &OpenXchangeResource::onFoldersRequestJobFinished);
         job->start();
     }
@@ -422,12 +409,12 @@ void OpenXchangeResource::retrieveItems(const Akonadi::Collection &collection)
     if (Settings::self()->useIncrementalUpdates()) {
         ObjectsLastSync lastSyncInfo;
         //qDebug( "lastSync=%llu", lastSyncInfo.lastSync( collection.id() ) );
-        OXA::ObjectsRequestDeltaJob *job = new OXA::ObjectsRequestDeltaJob(folder, lastSyncInfo.lastSync(collection.id()), this);
+        auto *job = new OXA::ObjectsRequestDeltaJob(folder, lastSyncInfo.lastSync(collection.id()), this);
         job->setProperty("collection", QVariant::fromValue(collection));
         connect(job, &OXA::UpdateUsersJob::result, this, &OpenXchangeResource::onObjectsRequestDeltaJobFinished);
         job->start();
     } else {
-        OXA::ObjectsRequestJob *job = new OXA::ObjectsRequestJob(folder, 0, OXA::ObjectsRequestJob::Modified, this);
+        auto *job = new OXA::ObjectsRequestJob(folder, 0, OXA::ObjectsRequestJob::Modified, this);
         connect(job, &OXA::UpdateUsersJob::result, this, &OpenXchangeResource::onObjectsRequestJobFinished);
         job->start();
     }
@@ -442,7 +429,7 @@ bool OpenXchangeResource::retrieveItem(const Akonadi::Item &item, const QSet<QBy
     object.setObjectId(remoteInformation.objectId());
     object.setModule(remoteInformation.module());
 
-    OXA::ObjectRequestJob *job = new OXA::ObjectRequestJob(object, this);
+    auto *job = new OXA::ObjectRequestJob(object, this);
     job->setProperty("item", QVariant::fromValue(item));
     connect(job, &OXA::UpdateUsersJob::result, this, &OpenXchangeResource::onObjectRequestJobFinished);
     job->start();
@@ -470,7 +457,7 @@ void OpenXchangeResource::itemAdded(const Akonadi::Item &item, const Akonadi::Co
         Q_ASSERT(false);
     }
 
-    OXA::ObjectCreateJob *job = new OXA::ObjectCreateJob(object, this);
+    auto *job = new OXA::ObjectCreateJob(object, this);
     job->setProperty("item", QVariant::fromValue(item));
     connect(job, &OXA::UpdateUsersJob::result, this, &OpenXchangeResource::onObjectCreateJobFinished);
     job->start();
@@ -499,7 +486,7 @@ void OpenXchangeResource::itemChanged(const Akonadi::Item &item, const QSet<QByt
         Q_ASSERT(false);
     }
 
-    OXA::ObjectModifyJob *job = new OXA::ObjectModifyJob(object, this);
+    auto *job = new OXA::ObjectModifyJob(object, this);
     job->setProperty("item", QVariant::fromValue(item));
     connect(job, &OXA::UpdateUsersJob::result, this, &OpenXchangeResource::onObjectModifyJobFinished);
     job->start();
@@ -516,7 +503,7 @@ void OpenXchangeResource::itemRemoved(const Akonadi::Item &item)
     object.setModule(remoteInformation.module());
     object.setLastModified(remoteInformation.lastModified());
 
-    OXA::ObjectDeleteJob *job = new OXA::ObjectDeleteJob(object, this);
+    auto *job = new OXA::ObjectDeleteJob(object, this);
     connect(job, &OXA::UpdateUsersJob::result, this, &OpenXchangeResource::onObjectDeleteJobFinished);
 
     job->start();
@@ -537,7 +524,7 @@ void OpenXchangeResource::itemMoved(const Akonadi::Item &item, const Akonadi::Co
     OXA::Folder destinationFolder;
     destinationFolder.setObjectId(newParentRemoteInformation.objectId());
 
-    OXA::ObjectMoveJob *job = new OXA::ObjectMoveJob(object, destinationFolder, this);
+    auto *job = new OXA::ObjectMoveJob(object, destinationFolder, this);
     job->setProperty("item", QVariant::fromValue(item));
     connect(job, &OXA::UpdateUsersJob::result, this, &OpenXchangeResource::onObjectMoveJobFinished);
 
@@ -571,7 +558,7 @@ void OpenXchangeResource::collectionAdded(const Akonadi::Collection &collection,
     // set user permissions of folder
     folder.setUserPermissions(userPermissions);
 
-    OXA::FolderCreateJob *job = new OXA::FolderCreateJob(folder, this);
+    auto *job = new OXA::FolderCreateJob(folder, this);
     job->setProperty("collection", QVariant::fromValue(collection));
     connect(job, &OXA::UpdateUsersJob::result, this, &OpenXchangeResource::onFolderCreateJobFinished);
     job->start();
@@ -595,7 +582,7 @@ void OpenXchangeResource::collectionChanged(const Akonadi::Collection &collectio
     folder.setTitle(collection.name());
     folder.setLastModified(remoteInformation.lastModified());
 
-    OXA::FolderModifyJob *job = new OXA::FolderModifyJob(folder, this);
+    auto *job = new OXA::FolderModifyJob(folder, this);
     job->setProperty("collection", QVariant::fromValue(collection));
     connect(job, &OXA::UpdateUsersJob::result, this, &OpenXchangeResource::onFolderModifyJobFinished);
 }
@@ -608,7 +595,7 @@ void OpenXchangeResource::collectionRemoved(const Akonadi::Collection &collectio
     folder.setObjectId(remoteInformation.objectId());
     folder.setLastModified(remoteInformation.lastModified());
 
-    OXA::FolderDeleteJob *job = new OXA::FolderDeleteJob(folder, this);
+    auto *job = new OXA::FolderDeleteJob(folder, this);
     connect(job, &OXA::UpdateUsersJob::result, this, &OpenXchangeResource::onFolderDeleteJobFinished);
 
     job->start();
@@ -627,7 +614,7 @@ void OpenXchangeResource::collectionMoved(const Akonadi::Collection &collection,
     OXA::Folder destinationFolder;
     destinationFolder.setObjectId(newParentRemoteInformation.objectId());
 
-    OXA::FolderMoveJob *job = new OXA::FolderMoveJob(folder, destinationFolder, this);
+    auto *job = new OXA::FolderMoveJob(folder, destinationFolder, this);
     job->setProperty("collection", QVariant::fromValue(collection));
     connect(job, &OXA::UpdateUsersJob::result, this, &OpenXchangeResource::onFolderMoveJobFinished);
 
@@ -660,7 +647,7 @@ void OpenXchangeResource::onObjectsRequestJobFinished(KJob *job)
         return;
     }
 
-    OXA::ObjectsRequestJob *requestJob = qobject_cast<OXA::ObjectsRequestJob *>(job);
+    auto *requestJob = qobject_cast<OXA::ObjectsRequestJob *>(job);
     Q_ASSERT(requestJob);
 
     Item::List items;
@@ -706,7 +693,7 @@ void OpenXchangeResource::onObjectsRequestDeltaJobFinished(KJob *job)
         return;
     }
 
-    OXA::ObjectsRequestDeltaJob *requestJob = qobject_cast<OXA::ObjectsRequestDeltaJob *>(job);
+    auto *requestJob = qobject_cast<OXA::ObjectsRequestDeltaJob *>(job);
     Q_ASSERT(requestJob);
 
     const Akonadi::Collection collection = requestJob->property("collection").value<Collection>();
@@ -785,7 +772,7 @@ void OpenXchangeResource::onObjectRequestJobFinished(KJob *job)
         return;
     }
 
-    OXA::ObjectRequestJob *requestJob = qobject_cast<OXA::ObjectRequestJob *>(job);
+    auto *requestJob = qobject_cast<OXA::ObjectRequestJob *>(job);
     Q_ASSERT(requestJob);
 
     const OXA::Object object = requestJob->object();
@@ -857,7 +844,7 @@ void OpenXchangeResource::onObjectCreateJobFinished(KJob *job)
         return;
     }
 
-    OXA::ObjectCreateJob *createJob = qobject_cast<OXA::ObjectCreateJob *>(job);
+    auto *createJob = qobject_cast<OXA::ObjectCreateJob *>(job);
     Q_ASSERT(createJob);
 
     const OXA::Object object = createJob->object();
@@ -877,7 +864,7 @@ void OpenXchangeResource::onObjectModifyJobFinished(KJob *job)
         return;
     }
 
-    OXA::ObjectModifyJob *modifyJob = qobject_cast<OXA::ObjectModifyJob *>(job);
+    auto *modifyJob = qobject_cast<OXA::ObjectModifyJob *>(job);
     Q_ASSERT(modifyJob);
 
     const OXA::Object object = modifyJob->object();
@@ -899,7 +886,7 @@ void OpenXchangeResource::onObjectMoveJobFinished(KJob *job)
         return;
     }
 
-    OXA::ObjectMoveJob *moveJob = qobject_cast<OXA::ObjectMoveJob *>(job);
+    auto *moveJob = qobject_cast<OXA::ObjectMoveJob *>(job);
     Q_ASSERT(moveJob);
 
     const OXA::Object object = moveJob->object();
@@ -936,7 +923,7 @@ static Collection folderToCollection(const OXA::Folder &folder, const Collection
     // set a unique name to make Akonadi happy
     collection.setName(folder.title() + QLatin1Char('_') + QUuid::createUuid().toString());
 
-    EntityDisplayAttribute *attribute = collection.attribute<EntityDisplayAttribute>(Collection::AddIfMissing);
+    auto *attribute = collection.attribute<EntityDisplayAttribute>(Collection::AddIfMissing);
     attribute->setDisplayName(folder.title());
 
     QStringList mimeTypes;
@@ -972,7 +959,7 @@ void OpenXchangeResource::onFoldersRequestJobFinished(KJob *job)
         return;
     }
 
-    OXA::FoldersRequestJob *requestJob = qobject_cast<OXA::FoldersRequestJob *>(job);
+    auto *requestJob = qobject_cast<OXA::FoldersRequestJob *>(job);
     Q_ASSERT(requestJob);
 
     Collection::List collections;
@@ -1010,7 +997,7 @@ void OpenXchangeResource::onFoldersRequestDeltaJobFinished(KJob *job)
         return;
     }
 
-    OXA::FoldersRequestDeltaJob *requestJob = qobject_cast<OXA::FoldersRequestDeltaJob *>(job);
+    auto *requestJob = qobject_cast<OXA::FoldersRequestDeltaJob *>(job);
     Q_ASSERT(requestJob);
 
     Collection::List changedCollections;
@@ -1072,7 +1059,7 @@ void OpenXchangeResource::onFolderCreateJobFinished(KJob *job)
         return;
     }
 
-    OXA::FolderCreateJob *createJob = qobject_cast<OXA::FolderCreateJob *>(job);
+    auto *createJob = qobject_cast<OXA::FolderCreateJob *>(job);
     Q_ASSERT(createJob);
 
     const OXA::Folder folder = createJob->folder();
@@ -1083,7 +1070,7 @@ void OpenXchangeResource::onFolderCreateJobFinished(KJob *job)
     remoteInformation.store(collection);
 
     // set matching icon
-    EntityDisplayAttribute *attribute = collection.attribute<EntityDisplayAttribute>(Collection::AddIfMissing);
+    auto *attribute = collection.attribute<EntityDisplayAttribute>(Collection::AddIfMissing);
     switch (folder.module()) {
     case OXA::Folder::Calendar:
         attribute->setIconName(QStringLiteral("view-calendar"));
@@ -1108,7 +1095,7 @@ void OpenXchangeResource::onFolderModifyJobFinished(KJob *job)
         return;
     }
 
-    OXA::FolderModifyJob *modifyJob = qobject_cast<OXA::FolderModifyJob *>(job);
+    auto *modifyJob = qobject_cast<OXA::FolderModifyJob *>(job);
     Q_ASSERT(modifyJob);
 
     const OXA::Folder folder = modifyJob->folder();
@@ -1130,7 +1117,7 @@ void OpenXchangeResource::onFolderMoveJobFinished(KJob *job)
         return;
     }
 
-    OXA::FolderMoveJob *moveJob = qobject_cast<OXA::FolderMoveJob *>(job);
+    auto *moveJob = qobject_cast<OXA::FolderMoveJob *>(job);
     Q_ASSERT(moveJob);
 
     const OXA::Folder folder = moveJob->folder();
@@ -1171,7 +1158,7 @@ void OpenXchangeResource::syncCollectionsRemoteIdCache()
     // copy the standard collections
     mCollectionsMap = mStandardCollectionsMap;
 
-    CollectionFetchJob *job = new CollectionFetchJob(mResourceCollection, CollectionFetchJob::Recursive, this);
+    auto *job = new CollectionFetchJob(mResourceCollection, CollectionFetchJob::Recursive, this);
     connect(job, &OXA::UpdateUsersJob::result, this, &OpenXchangeResource::onFetchResourceCollectionsFinished);
 }
 
