@@ -1,24 +1,10 @@
-/* Copyright 2009 Thomas McGuire <mcguire@kde.org>
+/*
+   SPDX-FileCopyrightText: 2010 Thomas McGuire <mcguire@kde.org>
 
-   This library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2 of the License or
-   ( at your option ) version 3 or, at the discretion of KDE e.V.
-   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "pop3resource.h"
-#include "settings.h"
 #include "jobs.h"
 
 #include <CollectionFetchJob>
@@ -237,13 +223,13 @@ void POP3Resource::doStateStep()
         Q_EMIT status(Running, i18n("Preparing transmission from \"%1\".", name()));
         Collection targetCollection(mSettings.targetCollection());
         if (targetCollection.isValid()) {
-            CollectionFetchJob *fetchJob = new CollectionFetchJob(targetCollection,
+            auto *fetchJob = new CollectionFetchJob(targetCollection,
                                                                   CollectionFetchJob::Base);
             fetchJob->start();
             connect(fetchJob, &CollectionFetchJob::result, this, &POP3Resource::targetCollectionFetchJobFinished);
         } else {
             // No target collection set in the config? Try requesting a default inbox
-            SpecialMailCollectionsRequestJob *requestJob = new SpecialMailCollectionsRequestJob(this);
+            auto *requestJob = new SpecialMailCollectionsRequestJob(this);
             requestJob->requestDefaultCollection(SpecialMailCollections::Inbox);
             requestJob->start();
             connect(requestJob, &SpecialMailCollectionsRequestJob::result, this, &POP3Resource::localFolderRequestJobFinished);
@@ -310,7 +296,7 @@ void POP3Resource::doStateStep()
     {
         qCDebug(POP3RESOURCE_LOG) << "================ Starting state Login ==========================";
 
-        LoginJob *loginJob = new LoginJob(mPopSession);
+        auto *loginJob = new LoginJob(mPopSession);
         connect(loginJob, &LoginJob::result, this, &POP3Resource::loginJobResult);
         loginJob->start();
         break;
@@ -319,7 +305,7 @@ void POP3Resource::doStateStep()
     {
         qCDebug(POP3RESOURCE_LOG) << "================ Starting state List ===========================";
         Q_EMIT status(Running, i18n("Fetching mail listing."));
-        ListJob *listJob = new ListJob(mPopSession);
+        auto *listJob = new ListJob(mPopSession);
         connect(listJob, &ListJob::result, this, &POP3Resource::listJobResult);
         listJob->start();
         break;
@@ -327,7 +313,7 @@ void POP3Resource::doStateStep()
     case UIDList:
     {
         qCDebug(POP3RESOURCE_LOG) << "================ Starting state UIDList ========================";
-        UIDListJob *uidListJob = new UIDListJob(mPopSession);
+        auto *uidListJob = new UIDListJob(mPopSession);
         connect(uidListJob, &UIDListJob::result, this, &POP3Resource::uidListJobResult);
         uidListJob->start();
         break;
@@ -362,7 +348,7 @@ void POP3Resource::doStateStep()
         if (mIdsToDownload.empty()) {
             advanceState(CheckRemovingMessage);
         } else {
-            FetchJob *fetchJob = new FetchJob(mPopSession);
+            auto *fetchJob = new FetchJob(mPopSession);
             fetchJob->setFetchIds(idsToDownload, sizesOfMessagesToDownload);
             connect(fetchJob, &FetchJob::result, this, &POP3Resource::fetchJobResult);
             connect(fetchJob, &FetchJob::messageFinished, this, &POP3Resource::messageFinished);
@@ -388,7 +374,7 @@ void POP3Resource::doStateStep()
     case Quit:
     {
         qCDebug(POP3RESOURCE_LOG) << "================ Starting state Quit ===========================";
-        QuitJob *quitJob = new QuitJob(mPopSession);
+        auto *quitJob = new QuitJob(mPopSession);
         connect(quitJob, &QuitJob::result, this, &POP3Resource::quitJobResult);
         quitJob->start();
         break;
@@ -469,7 +455,7 @@ void POP3Resource::targetCollectionFetchJobFinished(KJob *job)
         }
     }
     mTestLocalInbox = false;
-    Akonadi::CollectionFetchJob *fetchJob
+    auto *fetchJob
         = qobject_cast<Akonadi::CollectionFetchJob *>(job);
     Q_ASSERT(fetchJob);
     Q_ASSERT(fetchJob->collections().size() <= 1);
@@ -514,7 +500,7 @@ void POP3Resource::listJobResult(KJob *job)
         cancelSync(i18n("Error while getting the list of messages on the server.")
                    +QLatin1Char('\n') + job->errorString());
     } else {
-        ListJob *listJob = qobject_cast<ListJob *>(job);
+        auto *listJob = qobject_cast<ListJob *>(job);
         Q_ASSERT(listJob);
         mIdsToSizeMap = listJob->idList();
         mIdsToSaveValid = false;
@@ -529,7 +515,7 @@ void POP3Resource::uidListJobResult(KJob *job)
         cancelSync(i18n("Error while getting list of unique mail identifiers from the server.")
                    +QLatin1Char('\n') + job->errorString());
     } else {
-        UIDListJob *listJob = qobject_cast<UIDListJob *>(job);
+        auto *listJob = qobject_cast<UIDListJob *>(job);
         Q_ASSERT(listJob);
         mIdsToUidsMap = listJob->uidList();
         mUidsToIdsMap = listJob->idList();
@@ -584,10 +570,10 @@ void POP3Resource::messageFinished(int messageId, KMime::Message::Ptr message)
     item.setMimeType(QStringLiteral("message/rfc822"));
     item.setPayload<KMime::Message::Ptr>(message);
 
-    Akonadi::Pop3ResourceAttribute *attr = item.attribute<Akonadi::Pop3ResourceAttribute>(Akonadi::Item::AddIfMissing);
+    auto *attr = item.attribute<Akonadi::Pop3ResourceAttribute>(Akonadi::Item::AddIfMissing);
     attr->setPop3AccountName(identifier());
     Akonadi::MessageFlags::copyMessageFlags(*message, item);
-    ItemCreateJob *itemCreateJob = new ItemCreateJob(item, mTargetCollection);
+    auto *itemCreateJob = new ItemCreateJob(item, mTargetCollection);
 
     mPendingCreateJobs.insert(itemCreateJob, messageId);
     connect(itemCreateJob, &ItemCreateJob::result, this, &POP3Resource::itemCreateJobResult);
@@ -636,7 +622,7 @@ void POP3Resource::itemCreateJobResult(KJob *job)
         return;
     }
 
-    ItemCreateJob *createJob = qobject_cast<ItemCreateJob *>(job);
+    auto *createJob = qobject_cast<ItemCreateJob *>(job);
     Q_ASSERT(createJob);
 
     if (job->error()) {
@@ -798,7 +784,7 @@ void POP3Resource::deleteJobResult(KJob *job)
         return;
     }
 
-    DeleteJob *finishedDeleteJob = qobject_cast<DeleteJob *>(job);
+    auto *finishedDeleteJob = qobject_cast<DeleteJob *>(job);
     Q_ASSERT(finishedDeleteJob);
     Q_ASSERT(finishedDeleteJob == mDeleteJob);
     mDeletedIDs = finishedDeleteJob->deletedIDs();
